#[repr(u16)]pub enum MachineTypes {
Show 29 variants
Unknown = 0,
Alpha = 388,
Alpha64 = 644,
AM33 = 467,
AMD64 = 34_404,
ARM = 448,
ARM64 = 43_620,
ARMNT = 452,
EBC = 3_772,
I386 = 332,
IA64 = 512,
LoongArch32 = 25_138,
LoongArch64 = 25_188,
M32R = 36_929,
MIPS16 = 614,
MIPSFPU = 870,
MIPSFPU16 = 1_126,
PowerPC = 496,
PowerPCFP = 497,
R4000 = 358,
RISCV32 = 20_530,
RISCV64 = 20_580,
RISCV128 = 20_776,
SH3 = 418,
SH3DSP = 419,
SH4 = 422,
SH5 = 424,
Thumb = 450,
WCEMIPSV2 = 361,
}Expand description
The Machine field has one of the following values, which specify the CPU type. An image file can be run only on the specified machine or on a system that emulates the specified machine.
Variants
Unknown = 0
The content of this field is assumed to be applicable to any machine type
Alpha = 388
Alpha AXP, 32-bit address space
Alpha64 = 644
Alpha 64/AXP 64, 64-bit address space
AM33 = 467
Matsushita AM33
AMD64 = 34_404
x64
ARM = 448
ARM little endian
ARM64 = 43_620
ARM64 little endian
ARMNT = 452
ARM Thumb-2 little endian
EBC = 3_772
EFI byte code
I386 = 332
Intel 386 or later processors and compatible processors
IA64 = 512
Intel Itanium processor family
LoongArch32 = 25_138
LoongArch 32-bit processor family
LoongArch64 = 25_188
LoongArch 64-bit processor family
M32R = 36_929
Mitsubishi M32R little endian
MIPS16 = 614
MIPS16
MIPSFPU = 870
MIPS with FPU
MIPSFPU16 = 1_126
MIPS16 with FPU
PowerPC = 496
Power PC little endian
PowerPCFP = 497
Power PC with floating point support
R4000 = 358
MIPS little endian
RISCV32 = 20_530
RISC-V 32-bit address space
RISCV64 = 20_580
RISC-V 64-bit address space
RISCV128 = 20_776
RISC-V 128-bit address space
SH3 = 418
Hitachi SH3
SH3DSP = 419
Hitachi SH3 DSP
SH4 = 422
Hitachi SH4
SH5 = 424
Hitachi SH5
Thumb = 450
Thumb
WCEMIPSV2 = 361
MIPS little-endian WCE v2