#[repr(u16)]pub enum ARM64RelocationType {
Show 18 variants
Absolute = 0,
Addr32 = 1,
Addr32Nb = 2,
Branch26 = 3,
PageBaseRel21 = 4,
Rel21 = 5,
PageOffset12A = 6,
PageOffset12L = 7,
SecRel = 8,
SecRelLow12A = 9,
SecRelHigh12A = 10,
SecRelLow12L = 11,
Token = 12,
Section = 13,
Addr64 = 14,
Branch19 = 15,
Branch14 = 16,
Rel32 = 17,
}Expand description
Relocation type indicators for ARM64 processors.
Variants
Absolute = 0
The relocation is ignored.
Addr32 = 1
The 32-bit VA of the target.
Addr32Nb = 2
The 32-bit RVA of the target.
Branch26 = 3
The 26-bit relative displacement to the target, for B and BL instructions.
PageBaseRel21 = 4
The page base of the target, for ADRP instruction.
Rel21 = 5
The 12-bit relative displacement to the target, for instruction ADR.
PageOffset12A = 6
The 12-bit page offset of the target, for instructions ADD/ADDS (immediate) with zero shift.
PageOffset12L = 7
The 12-bit page offset of the target, for instruction LDR (indexed, unsigned immediate).
SecRel = 8
The 32-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
SecRelLow12A = 9
Bit 0:11 of section offset of the target, for instructions ADD/ADDS (immediate) with zero shift.
SecRelHigh12A = 10
Bit 12:23 of section offset of the target, for instructions ADD/ADDS (immediate) with zero shift.
SecRelLow12L = 11
Bit 0:11 of section offset of the target, for instruction LDR (indexed, unsigned immediate).
Token = 12
CLR token.
Section = 13
The 16-bit section index of the section that contains the target. This is used to support debugging information.
Addr64 = 14
The 64-bit VA of the relocation target.
Branch19 = 15
The 19-bit offset to the relocation target, for conditional B instruction.
Branch14 = 16
The 14-bit offset to the relocation target, for instructions TBZ and TBNZ.
Rel32 = 17
The 32-bit relative address from the byte following the relocation.