#[repr(u16)]pub enum M32RRelocationType {
Show 15 variants
Absolute = 0,
Addr32 = 1,
Addr32Nb = 2,
Addr24 = 3,
GPRel16 = 4,
PCRel24 = 5,
PCRel16 = 6,
PCRel8 = 7,
RefHalf = 8,
RefHi = 9,
RefLo = 10,
Pair = 11,
Section = 12,
SecRel = 13,
Token = 14,
}Expand description
Relocation type indicators for Mitsubishi M32R processors.
Variants
Absolute = 0
The relocation is ignored.
Addr32 = 1
The target’s 32-bit VA.
Addr32Nb = 2
The target’s 32-bit RVA.
Addr24 = 3
The target’s 24-bit VA.
GPRel16 = 4
The target’s 16-bit offset from the GP register.
PCRel24 = 5
The target’s 24-bit offset from the program counter (PC), shifted left by 2 bits and sign-extended.
PCRel16 = 6
The target’s 16-bit offset from the PC, shifted left by 2 bits and sign-extended.
PCRel8 = 7
The target’s 8-bit offset from the PC, shifted left by 2 bits and sign-extended.
RefHalf = 8
The 16 MSBs of the target VA.
RefHi = 9
The 16 MSBs of the target VA, adjusted for LSB sign extension. This is used for the first instruction in a two-instruction sequence that loads a full 32-bit address. This relocation must be immediately followed by a PAIR relocation whose SymbolTableIndex contains a signed 16-bit displacement that is added to the upper 16 bits that are taken from the location that is being relocated.
RefLo = 10
The 16 LSBs of the target VA.
Pair = 11
The relocation must follow the REFHI relocation. Its SymbolTableIndex contains a displacement and not an index into the symbol table.
Section = 12
The 16-bit section index of the section that contains the target. This is used to support debugging information.
SecRel = 13
The 32-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
Token = 14
The CLR token.