#[repr(u16)]pub enum MIPSRelocationType {
Show 15 variants
Absolute = 0,
RefHalf = 1,
RefWord = 2,
JMPAddr = 3,
RefHi = 4,
RefLo = 5,
GPRel = 6,
Literal = 7,
Section = 10,
SecRel = 11,
SecRelLo = 12,
SecRelHi = 13,
JMPAddr16 = 16,
RefWordNb = 34,
Pair = 37,
}Expand description
Relocation type indicators for MIPS processors.
Variants
Absolute = 0
The relocation is ignored.
RefHalf = 1
The high 16 bits of the target’s 32-bit VA.
RefWord = 2
The target’s 32-bit VA.
JMPAddr = 3
The low 26 bits of the target’s VA. This supports the MIPS J and JAL instructions.
RefHi = 4
The high 16 bits of the target’s 32-bit VA. This is used for the first instruction in a two-instruction sequence that loads a full address. This relocation must be immediately followed by a PAIR relocation whose SymbolTableIndex contains a signed 16-bit displacement that is added to the upper 16 bits that are taken from the location that is being relocated.
RefLo = 5
The low 16 bits of the target’s VA.
GPRel = 6
A 16-bit signed displacement of the target relative to the GP register.
Literal = 7
The same as MIPSRelocationType::GPRel.
Section = 10
The 16-bit section index of the section contains the target. This is used to support debugging information.
SecRel = 11
The 32-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
SecRelLo = 12
The low 16 bits of the 32-bit offset of the target from the beginning of its section.
SecRelHi = 13
The high 16 bits of the 32-bit offset of the target from the beginning of its section. A PAIR relocation must immediately follow this one. The SymbolTableIndex of the PAIR relocation contains a signed 16-bit displacement that is added to the upper 16 bits that are taken from the location that is being relocated.
JMPAddr16 = 16
The low 26 bits of the target’s VA. This supports the MIPS16 JAL instruction.
RefWordNb = 34
The target’s 32-bit RVA.
Pair = 37
The relocation is valid only when it immediately follows a REFHI or SECRELHI relocation. Its SymbolTableIndex contains a displacement and not an index into the symbol table.