#[repr(u16)]pub enum PowerPCRelocationType {
Show 18 variants
Absolute = 0,
Addr64 = 1,
Addr32 = 2,
Addr24 = 3,
Addr16 = 4,
Addr14 = 5,
Rel24 = 6,
Rel14 = 7,
Addr32Nb = 10,
SecRel = 11,
Section = 12,
SecRel16 = 15,
RefHi = 16,
RefLo = 17,
Pair = 18,
SecRelLo = 19,
GPRel = 21,
Token = 22,
}Expand description
Relocation type indicators for PowerPC processors.
Variants
Absolute = 0
The relocation is ignored.
Addr64 = 1
The 64-bit VA of the target.
Addr32 = 2
The 32-bit VA of the target.
Addr24 = 3
The low 24 bits of the VA of the target. This is valid only when the target symbol is absolute and can be sign-extended to its original value.
Addr16 = 4
The low 16 bits of the target’s VA.
Addr14 = 5
The low 14 bits of the target’s VA. This is valid only when the target symbol is absolute and can be sign-extended to its original value.
Rel24 = 6
A 24-bit PC-relative offset to the symbol’s location.
Rel14 = 7
A 14-bit PC-relative offset to the symbol’s location.
Addr32Nb = 10
The 32-bit RVA of the target.
SecRel = 11
The 32-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
Section = 12
The 16-bit section index of the section that contains the target. This is used to support debugging information.
SecRel16 = 15
The 16-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
RefHi = 16
The high 16 bits of the target’s 32-bit VA. This is used for the first instruction in a two-instruction sequence that loads a full address. This relocation must be immediately followed by a PAIR relocation whose SymbolTableIndex contains a signed 16-bit displacement that is added to the upper 16 bits that was taken from the location that is being relocated.
RefLo = 17
The low 16 bits of the target’s VA.
Pair = 18
A relocation that is valid only when it immediately follows a REFHI or SECRELHI relocation. Its SymbolTableIndex contains a displacement and not an index into the symbol table.
SecRelLo = 19
The low 16 bits of the 32-bit offset of the target from the beginning of its section.
GPRel = 21
The 16-bit signed displacement of the target relative to the GP register.
Token = 22
The CLR token.