#[repr(u16)]pub enum X86RelocationType {
Show 17 variants
Absolute = 0,
Addr64 = 1,
Addr32 = 2,
Addr32Nb = 3,
Rel32 = 4,
Rel321 = 5,
Rel322 = 6,
Rel323 = 7,
Rel324 = 8,
Rel325 = 9,
Section = 10,
SecRel = 11,
SecRel7 = 12,
Token = 13,
SRel32 = 14,
Pair = 15,
SSpan32 = 16,
}Expand description
Relocation type indicators for x64 and compatible processors.
Variants
Absolute = 0
The relocation is ignored.
Addr64 = 1
The 64-bit VA of the relocation target.
Addr32 = 2
The 32-bit VA of the relocation target.
Addr32Nb = 3
The 32-bit address without an image base (RVA).
Rel32 = 4
The 32-bit relative address from the byte following the relocation.
Rel321 = 5
The 32-bit address relative to byte distance 1 from the relocation.
Rel322 = 6
The 32-bit address relative to byte distance 2 from the relocation.
Rel323 = 7
The 32-bit address relative to byte distance 3 from the relocation.
Rel324 = 8
The 32-bit address relative to byte distance 4 from the relocation.
Rel325 = 9
The 32-bit address relative to byte distance 5 from the relocation.
Section = 10
The 16-bit section index of the section that contains the target. This is used to support debugging information.
SecRel = 11
The 32-bit offset of the target from the beginning of its section. This is used to support debugging information and static thread local storage.
SecRel7 = 12
A 7-bit unsigned offset from the base of the section that contains the target.
Token = 13
CLR tokens.
SRel32 = 14
A 32-bit signed span-dependent value emitted into the object.
Pair = 15
A pair that must immediately follow every span-dependent value.
SSpan32 = 16
A 32-bit signed span-dependent value that is applied at link time.